@@ -21,7 +21,7 @@
 
 const Clutter = imports.gi.Clutter;
 const EvView = imports.gi.EvinceView;
-const Gd = imports.gi.Gd;
+const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
@@ -34,6 +34,7 @@ const Documents = imports.documents;
 const Global = imports.global;
 const Manager = imports.manager;
 const Notifications = imports.notifications;
+const Properties = imports.properties;
 const Query = imports.query;
 const Tweener = imports.util.tweener;
 const Utils = imports.utils;
@@ -483,7 +484,7 @@ const OrganizeCollectionView = new Lang.Class({
         this._viewCol.add_attribute(this._rendererText,
                                     'text', OrganizeModelColumns.NAME);
 
-        this._rendererDetail = new Gd.StyledTextRenderer({ xpad: 16 });
+        this._rendererDetail = new GdPrivate.StyledTextRenderer({ xpad: 16 });
         this._rendererDetail.add_class('dim-label');
         this._viewCol.pack_start(this._rendererDetail, false);
         this._viewCol.set_cell_data_func(this._rendererDetail,
@@ -715,6 +716,8 @@ const SelectionController = new Lang.Class({
 });
 Signals.addSignalMethods(SelectionController.prototype);
 
+const _SELECTION_TOOLBAR_DEFAULT_WIDTH = 500;
+
 const SelectionToolbar = new Lang.Class({
     Name: 'SelectionToolbar',
 
@@ -726,30 +729,13 @@ const SelectionToolbar = new Lang.Class({
         this.widget = new Gtk.Toolbar({ show_arrow: false,
                                         icon_size: Gtk.IconSize.LARGE_TOOLBAR });
         this.widget.get_style_context().add_class('osd');
+        this.widget.set_size_request(_SELECTION_TOOLBAR_DEFAULT_WIDTH, -1);
 
         this.actor = new GtkClutter.Actor({ contents: this.widget,
                                             show_on_set_parent: false,
                                             opacity: 0 });
         Utils.alphaGtkWidget(this.actor.get_widget());
 
-        let widthConstraint =
-            new Clutter.BindConstraint({ source: this._parentActor,
-                                         coordinate: Clutter.BindCoordinate.WIDTH,
-                                         offset: - 300 });
-        this.actor.add_constraint(widthConstraint);
-        this.actor.connect('notify::width', Lang.bind(this,
-            function() {
-                let width = this._parentActor.width;
-                let offset = 300;
-
-                if (width > 1000)
-                    offset += (width - 1000);
-                else if (width < 600)
-                    offset -= (600 - width);
-
-                widthConstraint.offset = - offset;
-            }));
-
         this.actor.add_constraint(
             new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.X_AXIS,
                                           source: this._parentActor,
@@ -763,17 +749,26 @@ const SelectionToolbar = new Lang.Class({
         this._leftGroup = new Gtk.ToolItem({ child: this._leftBox });
         this.widget.insert(this._leftGroup, -1);
 
-        this._toolbarFavorite = new Gtk.ToggleButton({ child: new Gtk.Image ({ icon_name: 'emblem-favorite-symbolic',
-                                                                               pixel_size: 32 })});
-        this._leftBox.add(this._toolbarFavorite);
-        this._toolbarFavorite.connect('clicked', Lang.bind(this, this._onToolbarFavorite));
+        // open button
+        this._toolbarOpen = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'folder-symbolic',
+                                                                     pixel_size: 16 })});
+        this._leftBox.add(this._toolbarOpen);
+        this._toolbarOpen.connect('clicked', Lang.bind(this, this._onToolbarOpen));
 
+        // print button
         this._toolbarPrint = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'printer-symbolic',
-                                                                      pixel_size: 32 })});
+                                                                      pixel_size: 16 })});
         this._toolbarPrint.set_tooltip_text(_("Print"));
         this._leftBox.add(this._toolbarPrint);
         this._toolbarPrint.connect('clicked', Lang.bind(this, this._onToolbarPrint));
 
+        // trash button
+        this._toolbarTrash = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'user-trash-symbolic',
+                                                                      pixel_size: 16 })});
+        this._toolbarTrash.set_tooltip_text(_("Delete"));
+        this._leftBox.add(this._toolbarTrash);
+        this._toolbarTrash.connect('clicked', Lang.bind(this, this._onToolbarTrash));
+
         this._separator = new Gtk.SeparatorToolItem({ draw: false,
                                                       visible: true });
         this._separator.set_expand(true);
@@ -783,23 +778,20 @@ const SelectionToolbar = new Lang.Class({
         this._rightGroup = new Gtk.ToolItem({ child: this._rightBox });
         this.widget.insert(this._rightGroup, -1);
 
+        // organize button
         this._toolbarCollection = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'list-add-symbolic',
-                                                                           pixel_size: 32 })});
+                                                                           pixel_size: 16 })});
         this._toolbarCollection.set_tooltip_text(_("Organize"));
         this._rightBox.add(this._toolbarCollection);
         this._toolbarCollection.connect('clicked', Lang.bind(this, this._onToolbarCollection));
         this._toolbarCollection.show_all();
 
-        this._toolbarTrash = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'user-trash-symbolic',
-                                                                      pixel_size: 32 })});
-        this._toolbarTrash.set_tooltip_text(_("Delete"));
-        this._rightBox.add(this._toolbarTrash);
-        this._toolbarTrash.connect('clicked', Lang.bind(this, this._onToolbarTrash));
-
-        this._toolbarOpen = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'document-open-symbolic',
-                                                                     pixel_size: 32 })});
-        this._rightBox.add(this._toolbarOpen);
-        this._toolbarOpen.connect('clicked', Lang.bind(this, this._onToolbarOpen));
+        // properties button
+        this._toolbarProperties = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'document-properties-symbolic',
+                                                                           pixel_size: 16 })});
+        this._toolbarProperties.set_tooltip_text(_("Properties"));
+        this._rightBox.add(this._toolbarProperties);
+        this._toolbarProperties.connect('clicked', Lang.bind(this, this._onToolbarProperties));
 
         this.widget.show_all();
 
@@ -848,10 +840,9 @@ const SelectionToolbar = new Lang.Class({
 
     _setItemVisibility: function() {
         let apps = [];
-        let favCount = 0;
-        let showFavorite = true;
         let showTrash = true;
         let showPrint = true;
+        let showProperties = true;
         let showOpen = true;
 
         this._insideRefresh = true;
@@ -861,9 +852,6 @@ const SelectionToolbar = new Lang.Class({
             function(urn) {
                 let doc = Global.documentManager.getItemById(urn);
 
-                if (doc.favorite)
-                    favCount++;
-
                 if ((doc.defaultAppName) &&
                     (apps.indexOf(doc.defaultAppName) == -1))
                     apps.push(doc.defaultAppName);
@@ -872,11 +860,12 @@ const SelectionToolbar = new Lang.Class({
                 showPrint &= !doc.collection;
             }));
 
-        showFavorite &= ((favCount == 0) || (favCount == selection.length));
         showOpen = (apps.length > 0);
 
-        if (selection.length > 1)
+        if (selection.length > 1) {
             showPrint = false;
+            showProperties = false;
+        }
 
         let openLabel = null;
         if (apps.length == 1) {
@@ -888,28 +877,10 @@ const SelectionToolbar = new Lang.Class({
         }
         this._toolbarOpen.set_tooltip_text(openLabel);
 
-        if (showFavorite) {
-            let isFavorite = (favCount == selection.length);
-            let favoriteLabel = '';
-
-            if (isFavorite) {
-                favoriteLabel = _("Remove from favorites");
-                this._toolbarFavorite.set_active(true);
-                this._toolbarFavorite.get_style_context().add_class('documents-favorite');
-            } else {
-                favoriteLabel = _("Add to favorites");
-                this._toolbarFavorite.set_active(false);
-                this._toolbarFavorite.get_style_context().remove_class('documents-favorite');
-            }
-
-            this._toolbarFavorite.reset_style();
-            this._toolbarFavorite.set_tooltip_text(favoriteLabel);
-        }
-
         this._toolbarPrint.set_visible(showPrint);
+        this._toolbarProperties.set_visible(showProperties);
         this._toolbarTrash.set_visible(showTrash);
         this._toolbarOpen.set_visible(showOpen);
-        this._toolbarFavorite.set_visible(showFavorite);
 
         this._insideRefresh = false;
     },
@@ -941,19 +912,6 @@ const SelectionToolbar = new Lang.Class({
             }));
     },
 
-    _onToolbarFavorite: function(widget) {
-        if (this._insideRefresh)
-            return;
-
-        let selection = Global.selectionController.getSelection();
-
-        selection.forEach(Lang.bind(this,
-            function(urn) {
-                let doc = Global.documentManager.getItemById(urn);
-                doc.setFavorite(!doc.favorite);
-            }));
-    },
-
     _onToolbarTrash: function(widget) {
         let selection = Global.selectionController.getSelection();
 
@@ -964,6 +922,18 @@ const SelectionToolbar = new Lang.Class({
             }));
     },
 
+    _onToolbarProperties: function(widget) {
+        let selection = Global.selectionController.getSelection();
+        let dialog = new Properties.PropertiesDialog(selection[0]);
+        this._fadeOut();
+
+        dialog.widget.connect('response', Lang.bind(this,
+            function(widget, response) {
+                dialog.widget.destroy();
+                this._fadeIn();
+            }));
+    },
+
     _onToolbarPrint: function(widget) {
         let selection = Global.selectionController.getSelection();
 
